summaryrefslogtreecommitdiff
path: root/sound/usb/line6/toneport.c
diff options
context:
space:
mode:
Diffstat (limited to 'sound/usb/line6/toneport.c')
-rw-r--r--sound/usb/line6/toneport.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sound/usb/line6/toneport.c b/sound/usb/line6/toneport.c
index 24544b7ab476..77ad98c1a948 100644
--- a/sound/usb/line6/toneport.c
+++ b/sound/usb/line6/toneport.c
@@ -1,5 +1,5 @@
/*
* Line6 Linux USB driver - 0.9.1beta
*
* Copyright (C) 2004-2010 Markus Grabner (grabner@icg.tugraz.at)
* Emil Myhrman (emil.myhrman@gmail.com)
@@ -34,7 +34,7 @@ enum line6_device_type {
struct usb_line6_toneport {
/**
- Generic Line6 USB data.
+ Generic Line 6 USB data.
*/
struct usb_line6 line6;
@@ -1,5 +1,5 @@
/*
- * Line6 Linux USB driver - 0.9.1beta
+ * Line 6 Linux USB driver - 0.9.1beta
*
* Copyright (C) 2004-2010 Markus Grabner (grabner@icg.tugraz.at)